@@ -10,7 +10,7 @@ use Test::More 0.88;
 
 use Exporter qw{ import };
 
-our $VERSION = '0.010_01';
+our $VERSION = '0.011_01';
 
 our @EXPORT =		## no critic (ProhibitAutomaticExportation)
 qw{
@@ -212,7 +212,8 @@ done by C<goto &Test::More::is>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Mac-Pasteboard/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -220,7 +221,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013-2019 by Thomas R. Wyant, III
+Copyright (C) 2013-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
